<?php

namespace Drupal\todoist_api\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use GuzzleHttp\Exception\RequestException;

/**
 * Defines a confirmation form to confirm deletion of something by id.
 */
class AddTaskForm extends FormBase {

  /**
   * Rest cliet instance Todoist_api.
   *
   * @var object
   */
  protected $todoistclient;

  /**
   * {@inheritdoc}
   */
  public function getFormId() : string {
    return "add_task_form";
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    if (\Drupal::request()->get('id')) :
      $task = (object) $this->getTask(\Drupal::request()->get('id'));
    endif;
    $todist_help = Url::fromUri('https://todoist.com/Help/DatesTimes');
    $form['task'] = [
      '#type' => 'textfield',
      '#title' => $this->t("Task's heading"),
      '#description' => $this->t('Add task heading'),
      '#required' => TRUE,
      '#default_value' => $task->content ?? $task->content,
    ];

    $form['task_description'] = [
      '#type' => 'textfield',
      '#title' => $this->t("Task's Description"),
      '#description' => $this->t('Add description of the task.'),
      '#default_value' => $task->description ?? $task->description,
    ];

    $form['task_due_data'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Due data of the task:'),
      '#description' => $this->t("Add due data in mm/dd/yy format e.g fri at 2pm, today,
      today at 2, 10/5, 10/5/2006 at 2pm, 5 10 2010 etc. for more info please
      check this link %todoist_datatime.", ["%todoist_datatime" => Link::fromTextAndUrl('Todoist datatime', $todist_help)->toString()]),
      '#required' => TRUE,
      '#default_value' => $task->due['string'] ?? $task->due['string'],
    ];

    $form['actions']['#type'] = 'actions';

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
      '#button_type' => 'primary',
    ];

    $form['actions']['back'] = [
      '#type' => 'link',
      '#title' => $this->t('Back'),
      '#url' => Url::fromUri('internal:/admin/content/todoist'),
      '#attributes' => [
        'class' => [
          'button',
          'button--secondry',
        ],
      ],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $current_path = \Drupal::service('path.current')->getPath();
    $uri = 'tasks';
    $message = $this->t('A new task has been created.');
    $body = [
      "content" => $form_state->getValue('task'),
      "description" => $form_state->getValue('task_description'),
      "due_string" => $form_state->getValue('task_due_data'),
    ];

    try {
      if (preg_match('/\bedit\b/', $current_path)) {
        $body['type'] = 'edit';
        $id = \Drupal::request()->get('id');
        $message = $this->t('A task has been updated.');
      }
      $response = \Drupal::service('todoist_api.client')->post($uri, $body, $id);
      if ($response) :
        $this->messenger()->addStatus($message);
        $form_state->setRedirect('todoist_api.taskscontroller');
      endif;
    }
    catch (RequestException $exception) {
      \Drupal::logger('error_rest_client')->notice($exception->getMessage());
      $form_state->setErrorByName('task', $this->t('Application error. Please check log messages.'));
      $form_state->setRedirect('todoist_api.taskscontroller');
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getTask($task_id) {
    $uri = 'tasks';
    try {
      return \Drupal::service('todoist_api.client')->get($uri, NULL, $task_id);
    }
    catch (RequestException $exception) {
      \Drupal::logger('error_rest_client')->notice($exception->getMessage());
      return $this->messenger()->addError($this->t('Application error. Please try again later.'));
    }
  }

}
