<?php

namespace Drupal\todoist_api\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use GuzzleHttp\Exception\RequestException;
use Drupal\Component\Serialization\Json;

/**
 * Defines a confirmation form to confirm deletion of something by id.
 */
class CloseTaskForm extends ConfirmFormBase {

  /**
   * ID of the item to delete.
   *
   * @var int
   */
  protected $id;

  /**
   * ID of the item to delete.
   *
   * @var object
   */
  protected $todoistclient;

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, string $id = NULL) {
    $this->id = $id;
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // @todo: Do the deletion.
    $uri = 'tasks';
    $content_id = $this->id;
    try{
      $current_path = \Drupal::service('path.current')->getPath();
      if (preg_match('/\bclose\b/', $current_path)) {
        $body['type'] = 'close';
      }
      $response = \Drupal::service('todoist_api.client')->post($uri, $body, $content_id);
      if($response):
        $this->messenger()->addStatus($this->t('One task has been completed.'));
        $form_state->setRedirect('todoist_api.taskscontroller');
      endif;
    } catch( RequestException $exception) {
      \Drupal::logger('error_rest_client')->notice($exception->getMessage());
      $form_state->setErrorByName('task', $this->t('Application error. Please try again later.'));
      $form_state->setRedirect('todoist_api.taskscontroller');
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() : string {
    return "task_close_form";
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('todoist_api.taskscontroller');
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    $uri = 'tasks';
    $content_id = $this->id;
    return $this->t('Do you want to close the %id?', ['%id' => $this->id]);
  }

}
