<?php

namespace Drupal\todoist_api\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure todoist api settings.
 */
class TodoistConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'todoist_api.settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'todoist_api.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('todoist_api.settings');

    $form['api_endpoints'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Api endpoint Url'),
      '#description' => $this->t('Todoist API endpoints URL.'),
      '#default_value' => $config->get('api_endpoints'),
    ];

    $form['access_token'] = [
      '#type' => 'textfield',
      '#title' => $this->t('User Access Token'),
      '#description' => $this->t('Todoist API access token. You can get your ToDoist API token from !todoist.', ["!todoist" => "https://todoist.com/"]),
      '#default_value' => $config->get('access_token'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Retrieve the configuration.
    $this->config('todoist_api.settings')
      // Set the submitted configuration setting.
      ->set('api_endpoints', $form_state->getValue('api_endpoints'))
      // You can set multiple configurations at once by making
      // multiple calls to set().
      ->set('access_token', $form_state->getValue('access_token'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
