<?php

namespace Drupal\todoist_api\Rest;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\todoist_api\TodoIstapiClientbase;
use Drupal\todoist_api\Exception\TodoistapiException;
use GuzzleHttp\ClientInterface;
use GuzzleHttp\Exception\RequestException;
use Drupal\Component\Serialization\Json;
use Drupal\Core\Url;

Class Client extends TodoIstapiClientbase {

  /**
   * Guzzle\Client instance.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

   /**
   *  {@inheritdoc}
   *
   * @var \Todoist\ClientInterface
   */
  protected $todoistapiConfig;

  public function __construct(ConfigFactoryInterface $config_factory, ClientInterface $httpClient) {
    parent::__construct($config_factory);
    $this->todoistapiConfig = $config_factory->get('todoist_api.settings');
    $this->httpClient = $httpClient;
  }

  /**
   * {@inheritdoc}
   */
  public function get(string $uri, array $body = null, $id = null) {
    return $this->httpRequest('GET', $uri, $body, $id);
  }

  /**
   * {@inheritdoc}
   */
  public function post($uri, array $body = null, $id = null) {
    return $this->httpRequest('POST', $uri, $body, $id);
  }

  /**
   * {@inheritdoc}
   */
  public function put($uri, array $body = null, $id = null) {
    return $this->httpRequest('PUT', $uri, $body, $id);
  }

  /**
   * {@inheritdoc}
   */
  public function delete($uri, $id = null) {
    return $this->httpRequest('DELETE', $uri, null, $id);
  }

  /**
   * {@inheritdoc}
   */
  public function httpRequest($type, $uri, array $body = null, $id = null) {
    try{
      $bearer_token = 'Bearer '. $this->todoistapiConfig->get('access_token');
      $options = [
        'headers' => [
          'Content-Type' => 'application/json',
          'Authorization' => $bearer_token
        ]
      ];

      $end_point = $this->todoistapiConfig->get('api_endpoints');

      switch($type) {
        case 'DELETE':
          $end_point = $end_point . $uri . '/' . $id;
          break;
        case 'GET':
          $end_point = $end_point . $uri;
          $end_point .= !empty($id) ? '/' . $id : '';
          break;
        case 'POST':
          $end_point = !empty($body) ?  Url::fromUri($end_point . $uri, ['query' => $body])->toString() : $end_point . $uri . '/' . $id . '/' . 'close';
          break;
      }

      $request = $this->httpClient->request($type, $end_point, $options);

      switch($request->getStatusCode()){
        case '200':
          return json::decode($request->getBody()->getContents(), TRUE);
          break;
        case '204':
          return TRUE;
          break;
        default:
          $error = $request;
          throw new TodoistapiException('Error: Please try again later.');
          \Drupal::logger('error_rest_client')->notice($error);
        break;
      }

    } catch( RequestException $exception) {
      \Drupal::logger('error_rest_client')->notice($exception->getMessage());
    }
  }
}
